@@ -1,5 +1,6 @@
 from __future__ import division, absolute_import, print_function
 
-__all__ = ['parallel_strainrate_processing',
+__all__ = ['edge_processing',
+           'parallel_strainrate_processing',
            'parallel_plots']
 
