@@ -13,15 +13,12 @@ import distpy.calc.processing_commands as processing_commands
 
 
 def build_command_list(commandJson, data=None, dirout="scratch",
-                       datedir="none",datestring="none",nx=100,prf=10000,xaxis=None,nt=100,
-                       extended_list=[]):
+                       datedir="none",datestring="none",nx=100,prf=10000,xaxis=None,taxis=None,nt=100,
+                       extended_list=[],inline_plots=0):
     if xaxis is None:
         xaxis=numpy.arange(nx)
-    taxis = commandJson.get('taxis',None)
     if taxis is None:
         taxis=numpy.arange(nt)
-    # A convenience for Jupyter Notebooks - when developing workflows we sometimes want to inline plot views
-    inline_plots = commandJson.get('inline_plots',0)
     # initialize the command list that will eventually be executed.
     # This first one is anomalous - need a good way to initiate the top of the tree...
     # possibly this is a root...
@@ -83,7 +80,7 @@ def docs(command_list,commandJson):
 
                       This executes in one thread.
 '''
-def strainrate2summary(filename, xaxis, prf, dirout, commandJson, extended_list):
+def strainrate2summary(filename, xaxis, prf, dirout, commandJson, extended_list,data):
     # try to make a datestamp that WITSML could use...
     tokens = filename.split(os.sep)
     # the final token without its .npy is the unix timestamp
@@ -96,7 +93,8 @@ def strainrate2summary(filename, xaxis, prf, dirout, commandJson, extended_list)
     # Configure the hardware
     boxsize = commandJson.get('BOXSIZE', 500)
     extra_numpy.set_boxsize(boxsize)
-    data = numpy.load(filename)
+    if data is None:
+        data = numpy.load(filename)
     #print(data.shape)
     nx = data.shape[0]
     nt = data.shape[1]
@@ -107,9 +105,14 @@ def strainrate2summary(filename, xaxis, prf, dirout, commandJson, extended_list)
     # initialize the command list that will eventually be executed.
     # This first one is anomalous - need a good way to initiate the top of the tree...
     # possibly this is a root...
+    taxis = commandJson.get('taxis',None)
+    # A convenience for Jupyter Notebooks - when developing workflows we sometimes want to inline plot views
+    inline_plots = commandJson.get('inline_plots',0)
+
     command_list=build_command_list(commandJson, data=data,dirout=dirout,
                                     datedir=datedir,datestring=datestring,
-                                    nx=nx,prf=prf,xaxis=xaxis,nt=nt,extended_list=extended_list)
+                                    nx=nx,prf=prf,xaxis=xaxis,taxis=taxis,
+                                    nt=nt,extended_list=extended_list,inline_plots=inline_plots)
 
     # if documenting - that is one path...execution is the other
     if isDocs>0:
